summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextParag.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextParag.h')
-rw-r--r--lib/kotext/KoTextParag.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kotext/KoTextParag.h b/lib/kotext/KoTextParag.h
index 4ccc2196..e27a9afc 100644
--- a/lib/kotext/KoTextParag.h
+++ b/lib/kotext/KoTextParag.h
@@ -328,20 +328,20 @@ public:
/**
* Load a section of text from a oasis based xml tree.
* @param tqparent the xml element that has content as tqchildren.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace
*/
- void loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& context, uint& pos, bool stripLeadingSpace = false );
+ void loadOasisSpan( const TQDomElement& parent, KoOasisContext& context, uint& pos, bool stripLeadingSpace = false );
/**
* Load a section of text from a oasis based xml tree.
* @param tqparent the xml element that has content as tqchildren.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace
* @param hasTrailingSpace whether there was trailing literal whitespace in the span's text
*/
- void loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& context, uint& pos, bool stripLeadingSpace, bool *hasTrailingSpace );
+ void loadOasisSpan( const TQDomElement& parent, KoOasisContext& context, uint& pos, bool stripLeadingSpace, bool *hasTrailingSpace );
void applyListStyle( KoOasisContext& context, int restartNumbering, bool orderedList, bool heading, int level );
@@ -328,20 +328,20 @@ public:
/**
* Load a section of text from a oasis based xml tree.
- * @param tqparent the xml element that has content as tqchildren.
+ * @param parent the xml element that has content as tqchildren.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace
@@ -328,20 +328,20 @@ public:
/**
* Load a section of text from a oasis based xml tree.
- * @param tqparent the xml element that has content as tqchildren.
+ * @param parent the xml element that has content as tqchildren.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace